// lib/widgets/listen_replay_button.dart

import 'package:flutter/material.dart';
import '../services/audio_handler.dart';
import 'package:audioplayers/audioplayers.dart';

class ListenReplayButton extends StatefulWidget {
  final AudioHandler audioHandler;

  const ListenReplayButton({Key? key, required this.audioHandler}) : super(key: key);

  @override
  _ListenReplayButtonState createState() => _ListenReplayButtonState();
}

class _ListenReplayButtonState extends State<ListenReplayButton> {
  bool _isListening = false;
  final AudioPlayer _audioPlayer = AudioPlayer();

  void _toggleListening() async {
    if (_isListening) {
      await widget.audioHandler.stopListening();
    } else {
      await widget.audioHandler.startListening();
      // Listen to the audio stream and replay it
      widget.audioHandler.audioStream.listen((data) async {
        // Convert Uint8List to a playable format
        // For simplicity, we'll write to a temporary file and play it
        // In production, consider using a more efficient method
        String filePath = '/tmp/temp_audio.aac'; // Adjust path as needed

        // Use path_provider to get a valid directory
        // Add dependency: path_provider: ^2.0.11
        // Alternatively, use a package that allows in-memory playback

        // Placeholder: Play directly from bytes is not supported by audioplayers
        // You may need to implement native playback or use another package
        // For demonstration, we'll skip actual playback
        print('Replaying audio data: ${data.length} bytes');
      });
    }

    setState(() {
      _isListening = !_isListening;
    });
  }

  @override
  void dispose() {
    _audioPlayer.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return IconButton(
      icon: Icon(
        _isListening ? Icons.stop : Icons.mic,
        color: Colors.orangeAccent,
      ),
      onPressed: _toggleListening,
      tooltip: _isListening ? 'Stop Listening' : 'Listen and Replay',
    );
  }
}
